@@ -10,8 +10,7 @@ from boto.swf.exceptions import SWFResponseError
 from swf.constants import REGISTERED
 from swf.querysets.base import BaseQuerySet
 from swf.models.activity import ActivityType
-from swf.exceptions import (ResponseError, DoesNotExistError,
-                            InvalidCredentialsError)
+from swf.exceptions import ResponseError, DoesNotExistError
 
 from swf.utils import get_subkey
 
@@ -205,7 +204,6 @@ class ActivityTypeQuerySet(BaseQuerySet):
                 task_start_to_close_timeout=task_start_to_close_timeout,
             )
 
-
     def filter(self, domain=None,
                registration_status=REGISTERED,
                name=None, *args, **kwargs):
@@ -352,4 +350,4 @@ class ActivityTypeQuerySet(BaseQuerySet):
         )
         activity_type.save()
 
-        return activity_type
\ No newline at end of file
+        return activity_type
